Plugin: JS9Blink

### JS9 Image Blinking

The Image Blinking plugin allows you repeatedly to display a sequence of selected images at the specified blink rate. You also can blink selected images manually.

The Blink Images option turns on image blinking for all images that have their own blink option set. (Thus, it is not necessary to blink all of the loaded images.) The blink rate menu option allows you to choose the rate of re-display, with values ranging from 0.1 seconds to 30 seconds. The default is 1 second. You also can click the blink manually button to display the next image in the stack.

The blink sequence follows the order of the images listed in the image stack. This order can be changed by moving images up and down the stack. Note that the currently active image will be displayed with a green border. This is the image that responds to contrast/bias changes, region creation, etc.